#ifndef WELCOMESCREEN_H
#define WELCOMESCREEN_H

#include <QMainWindow>

namespace Ui {
    class WelcomeScreen;
}

class WelcomeScreen : public QMainWindow
{
    Q_OBJECT

public:
    explicit WelcomeScreen(QWidget *parent = 0);
    ~WelcomeScreen();

public slots:
    void keepBacklightOn();

private:
    Ui::WelcomeScreen *ui;

private slots:
    void on_pushButton_2_clicked();
    void on_comboBox_currentIndexChanged(int index);
    void on_pushButton_clicked();

};

#endif // WELCOMESCREEN_H
